@@ -1,12 +1,21 @@
 import unittest
+from typing import Any, Protocol
 
 from itemloaders import ItemLoader
 
 
-class InitializationTestMixin:
-    item_class = None
+class InitializationTestProtocol(Protocol):
+    item_class: Any
 
-    def test_keep_single_value(self):
+    def assertEqual(self, first: Any, second: Any, msg: Any = ...) -> None: ...
+
+    def assertIsInstance(self, obj: object, cls: type, msg: Any = None) -> None: ...
+
+
+class InitializationTestMixin:
+    item_class: Any = None
+
+    def test_keep_single_value(self: InitializationTestProtocol) -> None:
         """Loaded item should contain values from the initial item"""
         input_item = self.item_class(name="foo")
         il = ItemLoader(item=input_item)
@@ -14,7 +23,7 @@ class InitializationTestMixin:
         self.assertIsInstance(loaded_item, self.item_class)
         self.assertEqual(dict(loaded_item), {"name": ["foo"]})
 
-    def test_keep_list(self):
+    def test_keep_list(self: InitializationTestProtocol) -> None:
         """Loaded item should contain values from the initial item"""
         input_item = self.item_class(name=["foo", "bar"])
         il = ItemLoader(item=input_item)
@@ -22,7 +31,9 @@ class InitializationTestMixin:
         self.assertIsInstance(loaded_item, self.item_class)
         self.assertEqual(dict(loaded_item), {"name": ["foo", "bar"]})
 
-    def test_add_value_singlevalue_singlevalue(self):
+    def test_add_value_singlevalue_singlevalue(
+        self: InitializationTestProtocol,
+    ) -> None:
         """Values added after initialization should be appended"""
         input_item = self.item_class(name="foo")
         il = ItemLoader(item=input_item)
@@ -31,7 +42,7 @@ class InitializationTestMixin:
         self.assertIsInstance(loaded_item, self.item_class)
         self.assertEqual(dict(loaded_item), {"name": ["foo", "bar"]})
 
-    def test_add_value_singlevalue_list(self):
+    def test_add_value_singlevalue_list(self: InitializationTestProtocol) -> None:
         """Values added after initialization should be appended"""
         input_item = self.item_class(name="foo")
         il = ItemLoader(item=input_item)
@@ -40,7 +51,7 @@ class InitializationTestMixin:
         self.assertIsInstance(loaded_item, self.item_class)
         self.assertEqual(dict(loaded_item), {"name": ["foo", "item", "loader"]})
 
-    def test_add_value_list_singlevalue(self):
+    def test_add_value_list_singlevalue(self: InitializationTestProtocol) -> None:
         """Values added after initialization should be appended"""
         input_item = self.item_class(name=["foo", "bar"])
         il = ItemLoader(item=input_item)
@@ -49,7 +60,7 @@ class InitializationTestMixin:
         self.assertIsInstance(loaded_item, self.item_class)
         self.assertEqual(dict(loaded_item), {"name": ["foo", "bar", "qwerty"]})
 
-    def test_add_value_list_list(self):
+    def test_add_value_list_list(self: InitializationTestProtocol) -> None:
         """Values added after initialization should be appended"""
         input_item = self.item_class(name=["foo", "bar"])
         il = ItemLoader(item=input_item)
@@ -58,7 +69,7 @@ class InitializationTestMixin:
         self.assertIsInstance(loaded_item, self.item_class)
         self.assertEqual(dict(loaded_item), {"name": ["foo", "bar", "item", "loader"]})
 
-    def test_get_output_value_singlevalue(self):
+    def test_get_output_value_singlevalue(self: InitializationTestProtocol) -> None:
         """Getting output value must not remove value from item"""
         input_item = self.item_class(name="foo")
         il = ItemLoader(item=input_item)
@@ -67,7 +78,7 @@ class InitializationTestMixin:
         self.assertIsInstance(loaded_item, self.item_class)
         self.assertEqual(loaded_item, {"name": ["foo"]})
 
-    def test_get_output_value_list(self):
+    def test_get_output_value_list(self: InitializationTestProtocol) -> None:
         """Getting output value must not remove value from item"""
         input_item = self.item_class(name=["foo", "bar"])
         il = ItemLoader(item=input_item)
@@ -76,13 +87,13 @@ class InitializationTestMixin:
         self.assertIsInstance(loaded_item, self.item_class)
         self.assertEqual(loaded_item, {"name": ["foo", "bar"]})
 
-    def test_values_single(self):
+    def test_values_single(self: InitializationTestProtocol) -> None:
         """Values from initial item must be added to loader._values"""
         input_item = self.item_class(name="foo")
         il = ItemLoader(item=input_item)
         self.assertEqual(il._values.get("name"), ["foo"])
 
-    def test_values_list(self):
+    def test_values_list(self: InitializationTestProtocol) -> None:
         """Values from initial item must be added to loader._values"""
         input_item = self.item_class(name=["foo", "bar"])
         il = ItemLoader(item=input_item)
