@@ -1,7 +1,9 @@
 import functools
 import operator
 import platform
+import sys
 import unittest
+from typing import Any
 
 from itemloaders.utils import get_func_args
 
@@ -18,7 +20,7 @@ class UtilsPythonTestCase(unittest.TestCase):
             pass
 
         class A:
-            def __init__(self, a, b, c):
+            def __init__(self, a: Any, b: Any, c: Any):
                 pass
 
             def method(self, a, b, c):
@@ -47,13 +49,18 @@ class UtilsPythonTestCase(unittest.TestCase):
         self.assertEqual(get_func_args(str.split, stripself=True), ["sep", "maxsplit"])
         self.assertEqual(get_func_args(" ".join, stripself=True), ["iterable"])
 
-        if platform.python_implementation() == "CPython":
-            # doesn't work on CPython: https://bugs.python.org/issue42785
-            self.assertEqual(get_func_args(operator.itemgetter(2)), [])
-        elif platform.python_implementation() == "PyPy":
+        if sys.version_info >= (3, 13) or platform.python_implementation() == "PyPy":
+            # the correct and correctly extracted signature
             self.assertEqual(
                 get_func_args(operator.itemgetter(2), stripself=True), ["obj"]
             )
+        elif platform.python_implementation() == "CPython":
+            # ["args", "kwargs"] is a correct result for the pre-3.13 incorrect function signature
+            # [] is an incorrect result on even older CPython (https://github.com/python/cpython/issues/86951)
+            self.assertIn(
+                get_func_args(operator.itemgetter(2), stripself=True),
+                [[], ["args", "kwargs"]],
+            )
 
 
 if __name__ == "__main__":
